==> zio-aws-lexmodelsv2_3-5.17.166.1-sources.jar: zio/aws/lexmodelsv2/model/BotRecommendationStatus.scala <==
package zio.aws.lexmodelsv2.model
import scala.jdk.CollectionConverters.*
sealed trait BotRecommendationStatus {
  def unwrap: software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus
}
object BotRecommendationStatus {
  def wrap(
      value: software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus
  ): zio.aws.lexmodelsv2.model.BotRecommendationStatus = value match {
    case software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.PROCESSING =>
      val r = Processing
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.DELETING =>
      val r = Deleting
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.DELETED =>
      val r = Deleted
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.DOWNLOADING =>
      val r = Downloading
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.UPDATING =>
      val r = Updating
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.AVAILABLE =>
      val r = Available
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.FAILED =>
      val r = Failed
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.lexmodelsv2.model.BotRecommendationStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object Processing
      extends zio.aws.lexmodelsv2.model.BotRecommendationStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.PROCESSING
  }
  case object Deleting
      extends zio.aws.lexmodelsv2.model.BotRecommendationStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.DELETING
  }
  case object Deleted
      extends zio.aws.lexmodelsv2.model.BotRecommendationStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.DELETED
  }
  case object Downloading
      extends zio.aws.lexmodelsv2.model.BotRecommendationStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.DOWNLOADING
  }
  case object Updating
      extends zio.aws.lexmodelsv2.model.BotRecommendationStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.UPDATING
  }
  case object Available
      extends zio.aws.lexmodelsv2.model.BotRecommendationStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.AVAILABLE
  }
  case object Failed extends zio.aws.lexmodelsv2.model.BotRecommendationStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.FAILED
  }
}

==> zio-aws-lexmodelsv2_3-5.17.267.1-sources.jar: zio/aws/lexmodelsv2/model/BotRecommendationStatus.scala <==
package zio.aws.lexmodelsv2.model
import scala.jdk.CollectionConverters.*
sealed trait BotRecommendationStatus {
  def unwrap: software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus
}
object BotRecommendationStatus {
  def wrap(
      value: software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus
  ): zio.aws.lexmodelsv2.model.BotRecommendationStatus = value match {
    case software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.PROCESSING =>
      val r = Processing
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.DELETING =>
      val r = Deleting
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.DELETED =>
      val r = Deleted
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.DOWNLOADING =>
      val r = Downloading
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.UPDATING =>
      val r = Updating
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.AVAILABLE =>
      val r = Available
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.FAILED =>
      val r = Failed
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.STOPPING =>
      val r = Stopping
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.STOPPED =>
      val r = Stopped
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.lexmodelsv2.model.BotRecommendationStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object Processing
      extends zio.aws.lexmodelsv2.model.BotRecommendationStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.PROCESSING
  }
  case object Deleting
      extends zio.aws.lexmodelsv2.model.BotRecommendationStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.DELETING
  }
  case object Deleted
      extends zio.aws.lexmodelsv2.model.BotRecommendationStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.DELETED
  }
  case object Downloading
      extends zio.aws.lexmodelsv2.model.BotRecommendationStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.DOWNLOADING
  }
  case object Updating
      extends zio.aws.lexmodelsv2.model.BotRecommendationStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.UPDATING
  }
  case object Available
      extends zio.aws.lexmodelsv2.model.BotRecommendationStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.AVAILABLE
  }
  case object Failed extends zio.aws.lexmodelsv2.model.BotRecommendationStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.FAILED
  }
  case object Stopping
      extends zio.aws.lexmodelsv2.model.BotRecommendationStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.STOPPING
  }
  case object Stopped
      extends zio.aws.lexmodelsv2.model.BotRecommendationStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotRecommendationStatus.STOPPED
  }
}
